Class: ChildProcess::Windows::Process
- Inherits:
-
AbstractProcess
- Object
- AbstractProcess
- ChildProcess::Windows::Process
- Defined in:
- lib/childprocess/windows/process.rb
Constant Summary
Constants inherited from AbstractProcess
AbstractProcess::POLL_INTERVAL
Instance Attribute Summary collapse
-
#pid ⇒ Fixnum
readonly
The pid of the process after it has started.
Attributes inherited from AbstractProcess
Instance Method Summary collapse
Methods inherited from AbstractProcess
#alive?, #crashed?, #initialize, #poll_for_exit, #start
Constructor Details
This class inherits a constructor from ChildProcess::AbstractProcess
Instance Attribute Details
#pid ⇒ Fixnum (readonly)
Returns the pid of the process after it has started.
7 8 9 |
# File 'lib/childprocess/windows/process.rb', line 7 def pid @pid end |
Instance Method Details
#exited? ⇒ Boolean
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/childprocess/windows/process.rb', line 25 def exited? return true if @exit_code assert_started code = @handle.exit_code exited = code != PROCESS_STILL_ACTIVE log(:exited? => exited, :code => code) if exited @exit_code = code end exited end |
#io ⇒ Object
9 10 11 |
# File 'lib/childprocess/windows/process.rb', line 9 def io @io ||= Windows::IO.new end |
#stop(timeout = 3) ⇒ Object
13 14 15 16 17 18 19 20 21 22 23 |
# File 'lib/childprocess/windows/process.rb', line 13 def stop(timeout = 3) assert_started # just kill right away on windows. log "sending KILL" @handle.send(WIN_SIGKILL) poll_for_exit(timeout) ensure @handle.close end |